<?php
namespace BpotSingleTaxSelect;

if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'BpotSingleTaxSelect\Options_Page' ) ) :

class Options_Page 
{
    protected $selection_type = [];

    // CONSTRUCT
    public function __construct() {
        if ( \is_admin() ) {
            $this->set_selection_type_data();
			\add_action( 'admin_menu', [ $this, 'register_menu' ] );
            \add_action( 'admin_init', [ $this, 'register_settings' ] );
		}
    }

    // REGISTER MENU
    public function register_menu() {
		$page_hook = \add_options_page(
			\__( 'Single Taxonomy Selector Options', 'single-taxonomy-selector' ),
			\__( 'Single Taxonomy Selector', 'single-taxonomy-selector' ),
			'manage_options',
			STAXS_OPTION_PAGE_SLUG,
			[ $this, 'generate_page' ]
		);

		\add_action( $page_hook, [ $this, 'enqueue_assets' ] );
	}

    // RENDER OPTION PAGE HTML
    public function generate_page() {
		require_once STAXS_TEMPLATES_DIR . 'options-page.php';
	}

    // REGISTER OPTION SETTINGS
    public function register_settings() {
        $option_setting_sanitize = [
            'type' => 'array',
            'sanitize_callback' => [ $this, 'sanitize_array_callback' ],
            'default' => [],
        ];

        \register_setting(STAXS_OPTION_PAGE_GROUP, STAXS_OPTION_TAXONOMIES_FIELD_KEY, $option_setting_sanitize);
        \register_setting(STAXS_OPTION_PAGE_GROUP, STAXS_OPTION_SELECTION_TYPE_FIELD_KEY, $option_setting_sanitize);

        // ADD SECTION
        \add_settings_section(
            STAXS_OPTION_PAGE_SECTION,
            '',
            '',
            STAXS_OPTION_PAGE_SLUG
        );

        // ADD TAXONOMIES FIELD
        \add_settings_field(
            'taxonomy_checkboxes',
            \__( 'Apply To Taxonomies', 'single-taxonomy-selector' ),
            [$this, 'taxonomy_checkboxes_callback'],
            STAXS_OPTION_PAGE_SLUG,
            STAXS_OPTION_PAGE_SECTION
        );

        // ADD SELECTION TYPE FIELD
        \add_settings_field(
            'selection_type_checkboxes',
            \__( 'Type Of Selection', 'single-taxonomy-selector' ),
            [$this, 'selection_type_checkboxes_callback'],
            STAXS_OPTION_PAGE_SLUG,
            STAXS_OPTION_PAGE_SECTION
        );
    }

    // SANITIZE ARRAY CALLBACK
    public function sanitize_array_callback( $input ) {
        if ( !is_array( $input ) ) {
            return [];
        }
        $sanitized_array = array_map( 'sanitize_text_field', $input );
        return $sanitized_array;
    }

    // ENQUEUE ASSETS THIS OPTION PAGE
    public function enqueue_assets() {
		
	}

    // RENDER TAXONOMY CHECKBOXES
    public function taxonomy_checkboxes_callback() {
        $selected_taxonomies = \get_option(STAXS_OPTION_TAXONOMIES_FIELD_KEY, []);
        $taxonomies = \get_taxonomies(['public' => true], 'objects');
    
        if (!empty($taxonomies)) {
            foreach ($taxonomies as $taxonomy) {
                $taxonomy_name = $taxonomy->name;
                if( !$taxonomy->hierarchical ) {
                    continue;
                }
                $checked = in_array($taxonomy_name, (array) $selected_taxonomies) ? 'checked' : '';
                ?>
                <label>
                    <input type="checkbox" name="<?php echo \esc_attr(STAXS_OPTION_TAXONOMIES_FIELD_KEY); ?>[]" value="<?php echo \esc_attr($taxonomy_name); ?>" <?php echo \esc_attr($checked); ?>>
                    <?php echo \esc_html($taxonomy->label); ?>
                </label><br>
                <?php
            }
        } else {
            echo '<p>';
            \esc_html_e( 'No public taxonomies found.', 'single-taxonomy-selector' );
            echo '</p>';
        }
    }

    // RENDER SELECTION TYPE CHECKBOXES
    public function selection_type_checkboxes_callback() {
        $selected_type = \get_option(STAXS_OPTION_SELECTION_TYPE_FIELD_KEY, ['type' => STAXS_OPTION_SELECTION_TYPE_DEFAULT]);
        if (!empty($this->selection_type)) {
            foreach ($this->selection_type as $type_name => $type_label) {
                $checked = isset($selected_type['type']) && $type_name === $selected_type['type'] ? 'checked' : '';
                ?>
                <label>
                    <input type="radio" name="<?php echo \esc_attr(STAXS_OPTION_SELECTION_TYPE_FIELD_KEY); ?>[type]" value="<?php echo \esc_attr($type_name); ?>" <?php echo \esc_attr($checked); ?>>
                    <?php echo \esc_html($type_label); ?>
                </label><br>
                <?php
            }
        } else {
            echo '<p>';
            \esc_html_e( 'No selection type found.', 'single-taxonomy-selector' );
            echo '</p>';
        }
    }

    // SET SELECTION TYPE DATA
    public function set_selection_type_data() {
        $this->selection_type = [
            STAXS_OPTION_SELECTION_TYPES[0] => \__( 'Only one parent and one child can be selected.', 'single-taxonomy-selector' ),
            STAXS_OPTION_SELECTION_TYPES[1] => \__( 'All term can only choose one.', 'single-taxonomy-selector' ),
            STAXS_OPTION_SELECTION_TYPES[2] => \__( 'Child term can select multiple.', 'single-taxonomy-selector' ),
        ];
    }
}

endif;