<?php
namespace BpotSingleTaxSelect;

if ( ! defined( 'ABSPATH' ) ) exit;
if ( ! class_exists( 'BpotSingleTaxSelect\Custom_Walker_Taxonomies_Checklist' ) ) :

class Custom_Walker_Taxonomies_Checklist extends \Walker {
    public $tree_type = 'category';
    public $db_fields = [
        'parent' => 'parent',
        'id'     => 'term_id',
    ];

    public function walk($elements, $max_depth, ...$args) {
        $selected_cats = $args[0]['selected_cats'] ?? [];

        $checked_terms = [];
        $unchecked_terms = [];
        
        foreach ($elements as $element) {
            if (in_array($element->term_id, $selected_cats)) {
                $checked_terms[] = $element;
            } else {
                $unchecked_terms[] = $element;
            }
        }

        $sorted_elements = array_merge($checked_terms, $unchecked_terms);

        return parent::walk($sorted_elements, $max_depth, ...$args);
    }

    public function start_lvl(&$output, $depth = 0, $args = []) {
        $indent = str_repeat("\t", $depth);
        $output .= "\n$indent<ul class='children'>\n";
    }

    public function end_lvl(&$output, $depth = 0, $args = []) {
        $indent = str_repeat("\t", $depth);
        $output .= "$indent</ul>\n";
    }

    public function start_el(&$output, $term, $depth = 0, $args = [], $id = 0) {
        // VARIABLE
        $taxonomy = $args['taxonomy'] ?? 'category';
        $name = $taxonomy === 'category' ? 'post_category[]' : 'tax_input[' . $taxonomy . '][]';
        $selection_type = Helper::getSelectTypeOption();

        $depth_display = $depth + 1;
        $custom_id = "in-category-{$term->term_id}-{$depth_display}";

        $checked = in_array($term->term_id, $args['selected_cats']) ? 'checked="checked"' : '';
        $disabled = !empty($args['disabled']) && in_array($term->term_id, $args['disabled']) ? 'disabled="disabled"' : '';

        // SET CLASS
        $li_class = [ 'staxs-'.$selection_type ];
        if( in_array($selection_type, ['select-default', 'select-all-one']) ) {
            $li_class[] = 'staxs-all-radio-select';
        } else {
            $li_class[] = 'staxs-child-checkbox-select';
        }
        if( $checked ) {
            $li_class[] = 'popular-category';
        }

        $output .= sprintf(
            '<li id="%s" class="%s"><label class="selectit"><input value="%d" type="checkbox" name="%s" id="%s" %s %s> %s</label>',
            $custom_id,
            implode(' ', $li_class),
            $term->term_id,
            $name,
            $custom_id,
            $checked,
            $disabled,
            \esc_html($term->name)
        );
    }

    public function end_el(&$output, $term, $depth = 0, $args = []) {
        $output .= "</li>\n";
    }
}

endif;